@@ -1,24 +1,13 @@
 /*
-  Copyright (C) 2017-2018 Montel Laurent <montel@kde.org>
+  SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-only
 */
 
 #include "filtermailmangziptest.h"
-#include <MailImporter/FilterMailmanGzip>
 #include "filterimportertest.h"
-#include <qtest.h>
+#include <MailImporter/FilterMailmanGzip>
+#include <QTest>
 
 FilterMAilmangzipTest::FilterMAilmangzipTest(QObject *parent)
     : QObject(parent)
@@ -36,17 +25,18 @@ void FilterMAilmangzipTest::shouldImportData()
 void FilterMAilmangzipTest::canNotImportDataEmptyPath()
 {
     MailImporter::FilterMailmanGzip filter;
-    MailImporter::FilterInfo *info = new MailImporter::FilterInfo;
-    FilterImporterTest *importerTest = new FilterImporterTest(info);
+    MailImporter::FilterInfo info;
+    auto importerTest = new FilterImporterTest(&info);
     filter.setFilterImporter(importerTest);
-    filter.setFilterInfo(info);
+    filter.setFilterInfo(&info);
     filter.importMails(QStringList());
     QVERIFY(importerTest->filterImporterDataList().isEmpty());
+    delete importerTest;
 }
 
 void FilterMAilmangzipTest::canNotImportDataUnknowPath()
 {
-    //VERIFY it.
+    // VERIFY it.
 #if 0
     MailImporter::FilterMailmanGzip filter;
     MailImporter::FilterInfo *info = new MailImporter::FilterInfo;
